@@ -37,7 +37,7 @@
 #' @param defaultTheme plot theme to use: \code{\link[ggplot2]{theme_bw}} (default), \code{\link[ggplot2]{theme_grey}},
 #'   \code{\link[ggplot2]{theme_classic}} or custom.
 #' @param themeExtra any additional \code{\link[ggplot2]{theme}} settings that override default theme.
-#' 
+#' @return ggplot object
 #' @seealso \code{\link{computeHeatmap}} for computing data for heat map 
 #' 
 #' @export
@@ -149,9 +149,14 @@ createHeatmap <- function(data, x, y, fill,
 #' @param themeExtra any additional \code{\link[ggplot2]{theme}} settings that override default theme.
 #' @seealso \code{\link{computeHistogram}} and \code{\link{computeBarchart}} to
 #'   compute data for histogram
+#' @return ggplot object
 #' @export
 #' @examples
-#' \donttest{
+#' if(interactive()){
+#' # initialize connection to Lahman baseball database in Aster 
+#' conn = odbcDriverConnect(connection="driver={Aster ODBC Driver};
+#'                          server=<dbhost>;port=2406;database=<dbname>;uid=<user>;pwd=<pw>")
+#' 
 #' # AL teams pitching stats by decade
 #' bc = computeBarchart(channel=conn, tableName="pitching_enh", category="teamid", 
 #'                      aggregates=c("AVG(era) era", "AVG(whip) whip", "AVG(ktobb) ktobb"),
@@ -247,8 +252,8 @@ createHistogram <- function(data, x="bin_start", y="bin_count", fill=NULL, posit
       scaleGradient
      else if(!missing(fill))
        # scale_fill_brewer(palette = palette)
-       # scale_fill_discrete(palette = colorDiscretePalette(palette)) - won't work with legend 
-       scale_fill_manual(values = (colorDiscretePalette(palette))(length(unique(data[,fill]))))
+       # scale_fill_discrete(palette = getDiscretePaletteFactory(palette)) - won't work with legend 
+       scale_fill_manual(values = (getDiscretePaletteFactory(palette))(length(unique(data[,fill]))))
      else if(!missing(paletteValues)) 
        scale_fill_manual(values = paletteValues)
     ) +
@@ -316,6 +321,8 @@ createHistogram <- function(data, x="bin_start", y="bin_count", fill=NULL, posit
 #'   along the x-axis. Each value of \code{x} must have corresponding
 #'   percentiles calculated.
 #' @param fill name of a column with values to colour box plots
+#' @param value column name with percentile value. Usually default \code{'value'}
+#'   with exception of temporal percentiles that should use \code{'epoch'} value.
 #' @param useIQR logical indicates use of IQR interval to compute cutoff lower 
 #'   and upper bounds: \code{[Q1 - 1.5 * IQR, Q3 + 1.5 * IQR], IQR = Q3 - Q1}, 
 #'   if FALSE then use maximum and minimum bounds (all values).    
@@ -347,9 +354,14 @@ createHistogram <- function(data, x="bin_start", y="bin_count", fill=NULL, posit
 #' @param themeExtra any additional \code{\link[ggplot2]{theme}} settings that override default theme.
 #' 
 #' @export
+#' @return ggplot object
 #' @seealso \code{\link{computePercentiles}} for computing boxplot quartiles
 #' @examples
-#' \donttest{
+#' if(interactive()){
+#' # initialize connection to Lahman baseball database in Aster 
+#' conn = odbcDriverConnect(connection="driver={Aster ODBC Driver};
+#'                          server=<dbhost>;port=2406;database=<dbname>;uid=<user>;pwd=<pw>")
+#' 
 #' # boxplot of pitching ipouts for AL in 2000s
 #' ipop = computePercentiles(conn, "pitching", "ipouts")
 #' createBoxplot(ipop)
@@ -370,7 +382,7 @@ createHistogram <- function(data, x="bin_start", y="bin_count", fill=NULL, posit
 #' 
 #'  
 #' }
-createBoxplot <- function(data, x=NULL, fill=x, useIQR = FALSE,
+createBoxplot <- function(data, x = NULL, fill = x, value = 'value', useIQR = FALSE,
                           facet = NULL, ncol = 1, facetScales = "fixed",                          
                           paletteValues = NULL, palette = "Set1",
                           title = paste("Boxplots", ifelse(is.null(x), NULL, paste("by", x))), 
@@ -388,11 +400,11 @@ createBoxplot <- function(data, x=NULL, fill=x, useIQR = FALSE,
   }
   
   if (is.null(facet)) {
-    formu = as.formula(paste(x, '~', 'percentile'))
+    formu = (paste(x, '~', 'percentile'))
   }else {
-    formu = as.formula(paste(x, '+', paste(facet, collapse='+'), '~', 'percentile'))
+    formu = stats::as.formula(paste(x, '+', paste(facet, collapse='+'), '~', 'percentile'))
   }
-  ndata = dcast(data, formu)
+  ndata = dcast(data, formu, value.var=value)
   
   # calculate IQR-based bounds
   if (useIQR) {
@@ -412,7 +424,7 @@ createBoxplot <- function(data, x=NULL, fill=x, useIQR = FALSE,
       if(!missing(paletteValues))
         scale_fill_manual(values = paletteValues)
      else # if(!missing(palette))
-       scale_fill_manual(values = (colorDiscretePalette(palette))(length(unique(data[,fill]))))
+       scale_fill_manual(values = (getDiscretePaletteFactory(palette))(length(unique(data[,fill]))))
     ) +
     defaultTheme +
     labs(title=title, x=xlab, y=ylab) +
@@ -511,6 +523,7 @@ buildThemeFromParameters <- function(legendPosition, title, xlab, ylab, baseFami
 #' @param defaultTheme plot theme to use: \code{\link[ggplot2]{theme_bw}} (default), \code{\link[ggplot2]{theme_grey}},
 #'   \code{\link[ggplot2]{theme_classic}} or custom.
 #' @param themeExtra any additional \code{\link[ggplot2]{theme}} settings that override default theme.
+#' @return ggplot object
 #' @seealso \code{\link{computeAggregates}} computes data for the bubble chart.
 #' @export
 createBubblechart <- function(data, x, y, z, label = z, fill = NULL, 
@@ -541,7 +554,7 @@ createBubblechart <- function(data, x, y, z, label = z, fill = NULL,
       if(!missing(paletteValues))
         scale_fill_manual(values = paletteValues)
       else if(!missing(palette))
-        scale_fill_manual(values = (colorDiscretePalette(palette))(length(unique(data[,fill]))))
+        scale_fill_manual(values = (getDiscretePaletteFactory(palette))(length(unique(data[,fill]))))
     ) +
     defaultTheme +
     labs(title=title, x=xlab, y=ylab) +
@@ -590,7 +603,7 @@ createBubblechart <- function(data, x, y, z, label = z, fill = NULL,
 #' @param defaultTheme plot theme to use: \code{\link[ggplot2]{theme_bw}}, \code{\link[ggplot2]{theme_grey}},
 #'   \code{\link[ggplot2]{theme_classic}} (default) or custom.
 #' @param themeExtra any additional \code{\link[ggplot2]{theme}} settings that override default theme.
-#' 
+#' @return ggplot object
 #' @export
 createSlopegraph <- function(data, id, rankFrom, rankTo, 
                              reverse = TRUE, na.rm = FALSE, scaleFactor = 1,
@@ -603,14 +616,13 @@ createSlopegraph <- function(data, id, rankFrom, rankTo,
                              lineSize = 0.15, textSize = 3.75, 
                              panelGridColour = "black", panelGridSize = 0.1,
                              defaultTheme = theme_classic(base_size = baseSize, base_family = baseFamily),
-                             themeExtra = NULL
-) {
+                             themeExtra = NULL) {
   
   if (na.rm) {
-    data = data[complete.cases(data),]
+    data = data[stats::complete.cases(data),]
   }
   
-  data[, id] = reorder(data[, id], data[, rankTo])
+  data[, id] = stats::reorder(data[, id], data[, rankTo])
   data$up_or_down = sign(data[,rankTo] - data[,rankFrom])
   datam = melt(data, id=c(id, fromLabel, toLabel, "up_or_down"), measure=c(rankFrom, rankTo))
   
@@ -707,6 +719,48 @@ createSlopegraph <- function(data, id, rankFrom, rankTo,
 #' @seealso \code{\link{wordcloud}}
 #' 
 #' @export createWordcloud
+#' @examples
+#' if(interactive()){
+#' # initialize connection to Dallas database in Aster 
+#' conn = odbcDriverConnect(connection="driver={Aster ODBC Driver};
+#'                          server=<dbhost>;port=2406;database=<dbname>;uid=<user>;pwd=<pw>")
+#' 
+#' stopwords = c("a", "an", "the", "with")
+#' 
+#' # 2-gram tf-idf on offense table
+#' daypart_tfidf_2gram = computeTfIdf(conn, "public.dallaspoliceall", 
+#'                                    docId="extract('hour' from offensestarttime)::int/6",  
+#'                                    textColumns=c('offensedescription','offensenarrative'),
+#'                                    parser=nGram(2, delimiter='[  \\t\\b\\f\\r:\"]+'),
+#'                                    stopwords=stopwords)
+#' 
+#' toRace <- function(ch) {
+#'   switch(as.character(ch),
+#'          "M" = "Male",
+#'          "F" = "Female",
+#'          "0" = "Night",
+#'          "1" = "Morning",
+#'          "2" = "Day",
+#'          "3" = "Evening",
+#'          "C" = "C",
+#'          "Unknown")
+#' }
+#'                                   
+#' createDallasWordcloud <- function(tf_df, metric, slice, n, maxWords=25, size=750) {
+#'   words=with(tf_df$rs, tf_df$rs[docid==slice,])
+#'   
+#'   ## palette 
+#'   pal = rev(brewer.pal(8, "Set1"))[c(-3,-1)]
+#'   
+#'   createWordcloud(words$term, words[, metric], maxWords=maxWords, scale=c(4, 0.5), palette=pal, 
+#'                   title=paste("Top ", metric, "Offense", n, "- grams for", toRace(race)),
+#'                   file=paste0('wordclouds/',metric,'_offense_',n,'gram_',toRace(slice),'.png'), 
+#'                   width=size, height=size)
+#' }
+#' 
+#' createDallasWordcloud(daypart_tfidf_2gram, 'tf_idf', 0, n=2, maxWords=200, size=1300)
+#' 
+#' }
 createWordcloud <- function(words, freq, title="Wordcloud", 
                             scale=c(8,.2), minFreq=10, maxWords=40,
                             filename, format=c('png','bmp','jpeg','tiff','pdf'), 
@@ -723,15 +777,15 @@ createWordcloud <- function(words, freq, title="Wordcloud",
     gdev(filename, width=width, height=height, units=units, res=NULL)
   }
   
-  layout(matrix(c(1,2), nrow=2), heights=c(1,7))
-  par(mar=rep(0,4))
-  plot.new()
-  text(x=.5, y=.5, title, cex=titleFactor)
+  graphics::layout(matrix(c(1,2), nrow=2), heights=c(1,7))
+  graphics::par(mar=rep(0,4))
+  graphics::plot.new()
+  graphics::text(x=.5, y=.5, title, cex=titleFactor)
   wordcloud(words, freq, scale=scale, min.freq=minFreq,
             max.words=maxWords, random.order=FALSE, rot.per=.15, colors=palette, bg='transparent')
   
   if (!missing(filename)) {
-    dev.off()
+    grDevices::dev.off()
   }
   
 }
@@ -775,10 +829,14 @@ createWordcloud <- function(words, freq, title="Wordcloud",
 #' @param defaultTheme plot theme to use: \code{\link[ggplot2]{theme_bw}} (default), \code{\link[ggplot2]{theme_grey}},
 #'   \code{\link[ggplot2]{theme_classic}} or custom.
 #' @param themeExtra any additional \code{\link[ggplot2]{theme}} settings that override default theme.
-#' 
+#' @return ggplot object
 #' @export 
 #' @examples
-#' \donttest{
+#' if(interactive()){
+#' # initialize connection to Lahman baseball database in Aster 
+#' conn = odbcDriverConnect(connection="driver={Aster ODBC Driver};
+#'                          server=<dbhost>;port=2406;database=<dbname>;uid=<user>;pwd=<pw>")
+#' 
 #' pitchingInfo = getTableSummary(asterConn, tableName='pitching', 
 #'                                where='yearid between 2000 and 2013')
 #' battingInfo = getTableSummary(asterConn, tableName='batting', 
@@ -888,9 +946,9 @@ setTextLayerBin <- function(text, data, x, y, value, fill=NULL, position="dodge"
 applyFacet <- function(p, facet=NULL, scales, ncol) {
   if (!missing(facet) & length(facet) > 0) {
     if (length(facet) == 1) {
-      p = p + facet_wrap(as.formula(paste("~", facet)), ncol=ncol, scales=scales)
+      p = p + facet_wrap(stats::as.formula(paste("~", facet)), ncol=ncol, scales=scales)
     }else {
-      p = p + facet_grid(as.formula(paste(facet[[1]], "~", facet[[2]])), scales=scales)
+      p = p + facet_grid(stats::as.formula(paste(facet[[1]], "~", facet[[2]])), scales=scales)
     }   
   }
   
@@ -898,34 +956,38 @@ applyFacet <- function(p, facet=NULL, scales, ncol) {
 }
 
 
-# Generate gradient palette maker
-# 
-# inspired by 
-# http://stackoverflow.com/questions/13353213/gradient-of-n-colors-ranging-from-color-1-and-color-2
-# 
-# @param colors pair of colors for gradient range (min, max): default is \code{c('black','white')}
-# @return function that 
-# @seealso \code{\link{colorRampPalette}}
-#
-# @examples
-# paletteMaker = colorGradientPalette(c("orange","red"))
-# myPalette = paletteMaker(10)
-colorGradientPalette <- function(colors=c("black", "white")) {
-  colfunc = colorRampPalette(colors)
+#' Generate gradient palette maker
+#' 
+#' inspired by 
+#' http://stackoverflow.com/questions/13353213/gradient-of-n-colors-ranging-from-color-1-and-color-2
+#' 
+#' @param colors pair of colors for gradient range (min, max): default is \code{c('black','white')}
+#' @return function (factory) that creates linear gradient palette for given number of colors
+#' @seealso \code{\link{getDiscretePaletteFactory}}, \code{\link{colorRampPalette}}
+#' @export
+#' @examples
+#' paletteMaker = getGradientPaletteFactory(c("yellow","red"))
+#' myPalette = paletteMaker(10)
+getGradientPaletteFactory <- function(colors=c("black", "white")) {
+  colfunc = grDevices::colorRampPalette(colors)
   return(colfunc)
 }
 
-# Generate discrete palette maker
-# 
-# @param paletteName name of palette from \code{brewer.pal.info} in \code{RColorBrewer} package
-# 
-# @export
-# @examples
-# paletteMaker = colorDiscretePalette("PuOr")
-# myPalette = paletteMaker(25)
-colorDiscretePalette <- function(paletteName="Set1") {
-  n = brewer.pal.info[rownames(brewer.pal.info)==paletteName, 'maxcolors']
-  colfunc = colorRampPalette(brewer.pal(n, paletteName))
+#' Generate discrete palette maker
+#' 
+#' @param paletteName name of palette from \code{brewer.pal.info} in \code{RColorBrewer} package
+#' @return function (factory) that creates discrete palette with for number of colors
+#' @seealso \code{\link{getGradientPaletteFactory}}, \code{\link{colorRampPalette}}
+#' @export
+#' @examples
+#' paletteMaker = getDiscretePaletteFactory("PuOr")
+#' myPalette = paletteMaker(25)
+getDiscretePaletteFactory <- function(paletteName="Set1") {
+  n = brewer.pal.info[paletteName, 'maxcolors']
+  colfunc = grDevices::colorRampPalette(brewer.pal(n, paletteName))
+  
+  n = brewer.pal.info[paletteName,"maxcolors"]
+  getPalette = grDevices::colorRampPalette(brewer.pal(n, paletteName))
   return(colfunc)
 }
 
@@ -947,13 +1009,13 @@ theme_empty <- function (baseSize = 12, baseFamily = "")
           axis.ticks = element_blank(),
           axis.title.x = element_blank(),
           axis.title.y = element_blank(),
-          axis.ticks.length = unit(0, "lines"),
-          axis.ticks.margin = unit(0, "lines"), 
+          axis.ticks.length = grid::unit(0, "lines"),
+          axis.ticks.margin = grid::unit(0, "lines"), 
           legend.background = element_rect(colour = NA),
           legend.key = element_rect(colour = "grey80"), 
-          legend.key.size = unit(1.2, "lines"),
-          legend.key.height = unit(NA, "cm"), 
-          legend.key.width = unit(NA, "cm"),
+          legend.key.size = grid::unit(1.2, "lines"),
+          legend.key.height = grid::unit(NA, "cm"), 
+          legend.key.width = grid::unit(NA, "cm"),
           legend.text = element_text(family = baseFamily, 
                                      size = baseSize * 0.8),
           legend.text.align = 0, 
@@ -967,7 +1029,7 @@ theme_empty <- function (baseSize = 12, baseFamily = "")
           panel.border = element_blank(),
           panel.grid.major = element_blank(),
           panel.grid.minor = element_blank(),
-          panel.margin = unit(0.25, "lines"), 
+          panel.margin = grid::unit(0.25, "lines"), 
           strip.background = element_blank(),
           strip.text.x = element_text(family = baseFamily,
                                       size = baseSize * 0.8),
@@ -975,6 +1037,6 @@ theme_empty <- function (baseSize = 12, baseFamily = "")
           plot.background = element_blank(),
           plot.title = element_text(family = baseFamily,
                                     size = baseSize * 1.2),
-          plot.margin = unit(c(1, 0.5, 0.5, 0.5), "lines"))
+          plot.margin = grid::unit(c(1, 0.5, 0.5, 0.5), "lines"))
   
 }
\ No newline at end of file
